ImageView

Struct ImageView 

pub struct ImageView { /* private fields */ }
Image view.

Works on terminals that support the Kitty graphics protocol

The view supports shrink, fit, and scale sizing modes (shrink is the default), image alignment, and scrolling.

Implementations

Source

impl ImageView

pub fn image(&self) -> Option<&Image>

Image.

pub fn set_image(&mut self, image: Image)

Set image.

Examples found in repository?
examples/pdf.rs (line 77)
71fn set_page(cursive: &mut Cursive, index: usize) {
72    let image = {
73        let pages: &mut Pages = cursive.user_data().unwrap();
74        pages.index = index;
75        pages.images[index].take().unwrap()
76    };
77    cursive.call_on_name(NAME, |image_view: &mut ImageView| image_view.set_image(image));
78}
pub fn take_image(&mut self) -> Option<Image>

Take image.

Examples found in repository?
examples/pdf.rs (line 81)
80fn unset_page(cursive: &mut Cursive) {
81    let image = cursive.call_on_name(NAME, |image_view: &mut ImageView| image_view.take_image()).unwrap();
82    if let Some(image) = image {
83        let pages: &mut Pages = cursive.user_data().unwrap();
84        pages.images[pages.index] = Some(image);
85    }
86}
pub fn with_image(self, image: Image) -> Self

Set image.

Chainable.

Examples found in repository?
examples/gif.rs (lines 11-14)
8fn main() {
9    let mut cursive = default();
10
11    cursive.add_layer(Panel::new(ImageView::default().with_image(
12        // GIFs will always be RGBA
13        Image::new_stream_from_gif_file(FILE).expect("new_stream_from_gif_file"),
14    )));
15
16    cursive.add_global_callback('q', |cursive| cursive.quit());
17
18    cursive.run();
19}
More examples
Hide additional examples
examples/simple.rs (lines 14-19)
9fn main() {
10    let mut cursive = default();
11
12    // By default the image view uses "shrink" sizing
13
14    cursive.add_layer(Panel::new(ImageView::default().with_image(Image::new_file(
15        FILE,
16        false,
17        ImageFormat::PNG,
18        (96, 96),
19    ))));
20
21    cursive.add_global_callback('q', |cursive| cursive.quit());
22
23    cursive.run();
24}
examples/svg.rs (lines 12-16)
9fn main() {
10    let mut cursive = default();
11
12    cursive.add_layer(Panel::new(ImageView::default().with_image(
13        // SVG can be either PNG or RGBA (PNG is usually more efficient)
14        // Note that we can apply scaling during rendering
15        Image::new_stream_from_svg_file(FILE, ImageFormat::PNG, 2.5).expect("new_stream_from_svg_file"),
16    )));
17
18    cursive.add_global_callback('q', |cursive| cursive.quit());
19
20    cursive.run();
21}
examples/scrollable.rs (lines 18-23)
12fn main() {
13    let mut cursive = default();
14
15    cursive.add_layer(
16        Panel::new(
17            ImageView::default()
18                .with_image(
19                    // Note that RGBA is supported, too, if you need transparency
20                    Image::new_stream_from_jpeg_file(FILE, ImageFormat::RGB).expect("new_stream_from_jpeg_file"),
21                    // If you prefer to keep the image data in memory:
22                    // Image::new_owned_from_jpeg_file(FILE, ImageFormat::RGB, true).expect("new_owned_from_jpeg_file"),
23                )
24                .with_sizing(Sizing::original())
25                .scrollable()
26                .scroll_x(true),
27        )
28        .fixed_size((50, 20)),
29    );
30
31    cursive.add_global_callback('q', |cursive| cursive.quit());
32
33    cursive.run();
34}
examples/positioning.rs (line 22)
15fn main() {
16    let mut cursive = default();
17
18    cursive.add_layer(Panel::new(
19        ImageView::default()
20            // We're also showing the use of new_png_file(), which discovers the image size for us
21            // (requires the "png" feature)
22            .with_image(Image::new_png_file(FILE).expect("new_png_file"))
23            .with_name(NAME)
24            .fixed_size((50, 20)),
25    ));
26
27    cursive.add_global_callback('s', |cursive| {
28        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
29            image_view.set_sizing(match image_view.sizing() {
30                Sizing::Shrink => Sizing::Fit,
31                Sizing::Fit => Sizing::Scale(3.),
32                Sizing::Scale(_) => Sizing::Shrink,
33            })
34        });
35    });
36
37    cursive.add_global_callback('h', |cursive| {
38        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
39            image_view.set_align(match image_view.align() {
40                Align { h: HAlign::Left, v } => Align { h: HAlign::Center, v },
41                Align { h: HAlign::Center, v } => Align { h: HAlign::Right, v },
42                Align { h: HAlign::Right, v } => Align { h: HAlign::Left, v },
43            })
44        });
45    });
46
47    cursive.add_global_callback('v', |cursive| {
48        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
49            image_view.set_align(match image_view.align() {
50                Align { h, v: VAlign::Top } => Align { h, v: VAlign::Center },
51                Align { h, v: VAlign::Center } => Align { h, v: VAlign::Bottom },
52                Align { h, v: VAlign::Bottom } => Align { h, v: VAlign::Top },
53            })
54        });
55    });
56
57    cursive.add_global_callback('q', |cursive| cursive.quit());
58
59    cursive.run();
60}
pub fn sizing(&self) -> Sizing

Sizing.

Examples found in repository?
examples/positioning.rs (line 29)
15fn main() {
16    let mut cursive = default();
17
18    cursive.add_layer(Panel::new(
19        ImageView::default()
20            // We're also showing the use of new_png_file(), which discovers the image size for us
21            // (requires the "png" feature)
22            .with_image(Image::new_png_file(FILE).expect("new_png_file"))
23            .with_name(NAME)
24            .fixed_size((50, 20)),
25    ));
26
27    cursive.add_global_callback('s', |cursive| {
28        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
29            image_view.set_sizing(match image_view.sizing() {
30                Sizing::Shrink => Sizing::Fit,
31                Sizing::Fit => Sizing::Scale(3.),
32                Sizing::Scale(_) => Sizing::Shrink,
33            })
34        });
35    });
36
37    cursive.add_global_callback('h', |cursive| {
38        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
39            image_view.set_align(match image_view.align() {
40                Align { h: HAlign::Left, v } => Align { h: HAlign::Center, v },
41                Align { h: HAlign::Center, v } => Align { h: HAlign::Right, v },
42                Align { h: HAlign::Right, v } => Align { h: HAlign::Left, v },
43            })
44        });
45    });
46
47    cursive.add_global_callback('v', |cursive| {
48        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
49            image_view.set_align(match image_view.align() {
50                Align { h, v: VAlign::Top } => Align { h, v: VAlign::Center },
51                Align { h, v: VAlign::Center } => Align { h, v: VAlign::Bottom },
52                Align { h, v: VAlign::Bottom } => Align { h, v: VAlign::Top },
53            })
54        });
55    });
56
57    cursive.add_global_callback('q', |cursive| cursive.quit());
58
59    cursive.run();
60}
pub fn set_sizing(&mut self, sizing: Sizing)

Set sizing.

Examples found in repository?
examples/positioning.rs (lines 29-33)
15fn main() {
16    let mut cursive = default();
17
18    cursive.add_layer(Panel::new(
19        ImageView::default()
20            // We're also showing the use of new_png_file(), which discovers the image size for us
21            // (requires the "png" feature)
22            .with_image(Image::new_png_file(FILE).expect("new_png_file"))
23            .with_name(NAME)
24            .fixed_size((50, 20)),
25    ));
26
27    cursive.add_global_callback('s', |cursive| {
28        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
29            image_view.set_sizing(match image_view.sizing() {
30                Sizing::Shrink => Sizing::Fit,
31                Sizing::Fit => Sizing::Scale(3.),
32                Sizing::Scale(_) => Sizing::Shrink,
33            })
34        });
35    });
36
37    cursive.add_global_callback('h', |cursive| {
38        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
39            image_view.set_align(match image_view.align() {
40                Align { h: HAlign::Left, v } => Align { h: HAlign::Center, v },
41                Align { h: HAlign::Center, v } => Align { h: HAlign::Right, v },
42                Align { h: HAlign::Right, v } => Align { h: HAlign::Left, v },
43            })
44        });
45    });
46
47    cursive.add_global_callback('v', |cursive| {
48        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
49            image_view.set_align(match image_view.align() {
50                Align { h, v: VAlign::Top } => Align { h, v: VAlign::Center },
51                Align { h, v: VAlign::Center } => Align { h, v: VAlign::Bottom },
52                Align { h, v: VAlign::Bottom } => Align { h, v: VAlign::Top },
53            })
54        });
55    });
56
57    cursive.add_global_callback('q', |cursive| cursive.quit());
58
59    cursive.run();
60}
pub fn with_sizing(self, sizing: Sizing) -> Self

Set sizing.

Chainable.

Examples found in repository?
examples/scrollable.rs (line 24)
12fn main() {
13    let mut cursive = default();
14
15    cursive.add_layer(
16        Panel::new(
17            ImageView::default()
18                .with_image(
19                    // Note that RGBA is supported, too, if you need transparency
20                    Image::new_stream_from_jpeg_file(FILE, ImageFormat::RGB).expect("new_stream_from_jpeg_file"),
21                    // If you prefer to keep the image data in memory:
22                    // Image::new_owned_from_jpeg_file(FILE, ImageFormat::RGB, true).expect("new_owned_from_jpeg_file"),
23                )
24                .with_sizing(Sizing::original())
25                .scrollable()
26                .scroll_x(true),
27        )
28        .fixed_size((50, 20)),
29    );
30
31    cursive.add_global_callback('q', |cursive| cursive.quit());
32
33    cursive.run();
34}
More examples
Hide additional examples
examples/pdf.rs (line 23)
10fn main() {
11    let mut cursive = default();
12
13    // The constructor returns a vector of images, one for each page in the PDF
14    // PDF pages can be either PNG or RGBA (PNG is usually more efficient)
15    // Note that we can apply scaling during rendering
16    let images = Image::new_owned_from_pdf_file(FILE, ImageFormat::PNG, 3., false).expect("new_owned_from_pdf_file");
17
18    cursive.set_user_data(Pages::new(images));
19
20    cursive.add_layer(
21        Dialog::around(
22            Panel::new(
23                ImageView::default().with_sizing(Sizing::original()).with_name(NAME).scrollable().scroll_x(true),
24            )
25            .fixed_size((50, 30)),
26        )
27        .button("Previous", |cursive| flip_page(cursive, -1))
28        .button("Next", |cursive| flip_page(cursive, 1)),
29    );
30
31    select_page(&mut cursive, 0);
32
33    cursive.add_global_callback('q', |cursive| cursive.quit());
34
35    cursive.run();
36}
pub fn align(&self) -> Align

Align.

Examples found in repository?
examples/positioning.rs (line 39)
15fn main() {
16    let mut cursive = default();
17
18    cursive.add_layer(Panel::new(
19        ImageView::default()
20            // We're also showing the use of new_png_file(), which discovers the image size for us
21            // (requires the "png" feature)
22            .with_image(Image::new_png_file(FILE).expect("new_png_file"))
23            .with_name(NAME)
24            .fixed_size((50, 20)),
25    ));
26
27    cursive.add_global_callback('s', |cursive| {
28        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
29            image_view.set_sizing(match image_view.sizing() {
30                Sizing::Shrink => Sizing::Fit,
31                Sizing::Fit => Sizing::Scale(3.),
32                Sizing::Scale(_) => Sizing::Shrink,
33            })
34        });
35    });
36
37    cursive.add_global_callback('h', |cursive| {
38        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
39            image_view.set_align(match image_view.align() {
40                Align { h: HAlign::Left, v } => Align { h: HAlign::Center, v },
41                Align { h: HAlign::Center, v } => Align { h: HAlign::Right, v },
42                Align { h: HAlign::Right, v } => Align { h: HAlign::Left, v },
43            })
44        });
45    });
46
47    cursive.add_global_callback('v', |cursive| {
48        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
49            image_view.set_align(match image_view.align() {
50                Align { h, v: VAlign::Top } => Align { h, v: VAlign::Center },
51                Align { h, v: VAlign::Center } => Align { h, v: VAlign::Bottom },
52                Align { h, v: VAlign::Bottom } => Align { h, v: VAlign::Top },
53            })
54        });
55    });
56
57    cursive.add_global_callback('q', |cursive| cursive.quit());
58
59    cursive.run();
60}
pub fn set_align(&mut self, align: Align)

Set align.

Examples found in repository?
examples/positioning.rs (lines 39-43)
15fn main() {
16    let mut cursive = default();
17
18    cursive.add_layer(Panel::new(
19        ImageView::default()
20            // We're also showing the use of new_png_file(), which discovers the image size for us
21            // (requires the "png" feature)
22            .with_image(Image::new_png_file(FILE).expect("new_png_file"))
23            .with_name(NAME)
24            .fixed_size((50, 20)),
25    ));
26
27    cursive.add_global_callback('s', |cursive| {
28        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
29            image_view.set_sizing(match image_view.sizing() {
30                Sizing::Shrink => Sizing::Fit,
31                Sizing::Fit => Sizing::Scale(3.),
32                Sizing::Scale(_) => Sizing::Shrink,
33            })
34        });
35    });
36
37    cursive.add_global_callback('h', |cursive| {
38        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
39            image_view.set_align(match image_view.align() {
40                Align { h: HAlign::Left, v } => Align { h: HAlign::Center, v },
41                Align { h: HAlign::Center, v } => Align { h: HAlign::Right, v },
42                Align { h: HAlign::Right, v } => Align { h: HAlign::Left, v },
43            })
44        });
45    });
46
47    cursive.add_global_callback('v', |cursive| {
48        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
49            image_view.set_align(match image_view.align() {
50                Align { h, v: VAlign::Top } => Align { h, v: VAlign::Center },
51                Align { h, v: VAlign::Center } => Align { h, v: VAlign::Bottom },
52                Align { h, v: VAlign::Bottom } => Align { h, v: VAlign::Top },
53            })
54        });
55    });
56
57    cursive.add_global_callback('q', |cursive| cursive.quit());
58
59    cursive.run();
60}
pub fn with_align(self, align: Align) -> Self

Set align.

Chainable.