ImageView

Struct ImageView 

pub struct ImageView { /* private fields */ }
Image view.

Works on terminals that support the Kitty graphics protocol

The view supports shrink, fit, and scale sizing modes (shrink is the default), image alignment, and scrolling.

Implementations

Source

impl ImageView

pub fn image(&self) -> Option<&Image>

Image.

pub fn set_image(&mut self, image: Image)

Set image.

pub fn with_image(self, image: Image) -> Self

Set image.

Chainable.

Examples found in repository?
examples/simple.rs (lines 14-19)
9fn main() {
10    let mut cursive = default();
11
12    // By default the image view uses "shrink" sizing
13
14    cursive.add_layer(Panel::new(ImageView::default().with_image(Image::new_file(
15        FILE,
16        false,
17        ImageFormat::PNG,
18        (96, 96),
19    ))));
20
21    cursive.add_global_callback('q', |cursive| cursive.quit());
22
23    cursive.run();
24}
More examples
Hide additional examples
examples/scrollable.rs (lines 18-24)
12fn main() {
13    let mut cursive = default();
14
15    cursive.add_layer(
16        Panel::new(
17            ImageView::default()
18                .with_image(
19                    // This will decode the JPEG file on-demand
20                    // Note that RGBA is supported, too, if you need transparency
21                    Image::new_stream_from_jpeg_file(FILE, ImageFormat::RGB).expect("new_stream_from_jpeg_file"),
22                    // If you prefer to keep the image data in memory:
23                    // Image::new_owned_from_jpeg_file(FILE, ImageFormat::RGB, true).expect("new_owned_from_jpeg_file"),
24                )
25                .with_sizing(Sizing::original())
26                .scrollable()
27                .scroll_x(true),
28        )
29        .fixed_size((50, 20)),
30    );
31
32    cursive.add_global_callback('q', |cursive| cursive.quit());
33
34    cursive.run();
35}
examples/positioning.rs (line 23)
18fn main() {
19    let mut cursive = default();
20
21    cursive.add_layer(Panel::new(
22        ImageView::default()
23            .with_image(Image::new_png_file(FILE).expect("new_png_file"))
24            .with_name(NAME)
25            .fixed_size((50, 20)),
26    ));
27
28    cursive.add_global_callback('s', |cursive| {
29        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
30            image_view.set_sizing(match image_view.sizing() {
31                Sizing::Shrink => Sizing::Fit,
32                Sizing::Fit => Sizing::Scale(3.),
33                Sizing::Scale(_) => Sizing::Shrink,
34            })
35        });
36    });
37
38    cursive.add_global_callback('h', |cursive| {
39        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
40            image_view.set_align(match image_view.align() {
41                Align { h: HAlign::Left, v } => Align { h: HAlign::Center, v },
42                Align { h: HAlign::Center, v } => Align { h: HAlign::Right, v },
43                Align { h: HAlign::Right, v } => Align { h: HAlign::Left, v },
44            })
45        });
46    });
47
48    cursive.add_global_callback('v', |cursive| {
49        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
50            image_view.set_align(match image_view.align() {
51                Align { h, v: VAlign::Top } => Align { h, v: VAlign::Center },
52                Align { h, v: VAlign::Center } => Align { h, v: VAlign::Bottom },
53                Align { h, v: VAlign::Bottom } => Align { h, v: VAlign::Top },
54            })
55        });
56    });
57
58    cursive.add_global_callback('q', |cursive| cursive.quit());
59
60    cursive.run();
61}
pub fn sizing(&self) -> Sizing

Sizing.

Examples found in repository?
examples/positioning.rs (line 30)
18fn main() {
19    let mut cursive = default();
20
21    cursive.add_layer(Panel::new(
22        ImageView::default()
23            .with_image(Image::new_png_file(FILE).expect("new_png_file"))
24            .with_name(NAME)
25            .fixed_size((50, 20)),
26    ));
27
28    cursive.add_global_callback('s', |cursive| {
29        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
30            image_view.set_sizing(match image_view.sizing() {
31                Sizing::Shrink => Sizing::Fit,
32                Sizing::Fit => Sizing::Scale(3.),
33                Sizing::Scale(_) => Sizing::Shrink,
34            })
35        });
36    });
37
38    cursive.add_global_callback('h', |cursive| {
39        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
40            image_view.set_align(match image_view.align() {
41                Align { h: HAlign::Left, v } => Align { h: HAlign::Center, v },
42                Align { h: HAlign::Center, v } => Align { h: HAlign::Right, v },
43                Align { h: HAlign::Right, v } => Align { h: HAlign::Left, v },
44            })
45        });
46    });
47
48    cursive.add_global_callback('v', |cursive| {
49        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
50            image_view.set_align(match image_view.align() {
51                Align { h, v: VAlign::Top } => Align { h, v: VAlign::Center },
52                Align { h, v: VAlign::Center } => Align { h, v: VAlign::Bottom },
53                Align { h, v: VAlign::Bottom } => Align { h, v: VAlign::Top },
54            })
55        });
56    });
57
58    cursive.add_global_callback('q', |cursive| cursive.quit());
59
60    cursive.run();
61}
pub fn set_sizing(&mut self, sizing: Sizing)

Set sizing.

Examples found in repository?
examples/positioning.rs (lines 30-34)
18fn main() {
19    let mut cursive = default();
20
21    cursive.add_layer(Panel::new(
22        ImageView::default()
23            .with_image(Image::new_png_file(FILE).expect("new_png_file"))
24            .with_name(NAME)
25            .fixed_size((50, 20)),
26    ));
27
28    cursive.add_global_callback('s', |cursive| {
29        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
30            image_view.set_sizing(match image_view.sizing() {
31                Sizing::Shrink => Sizing::Fit,
32                Sizing::Fit => Sizing::Scale(3.),
33                Sizing::Scale(_) => Sizing::Shrink,
34            })
35        });
36    });
37
38    cursive.add_global_callback('h', |cursive| {
39        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
40            image_view.set_align(match image_view.align() {
41                Align { h: HAlign::Left, v } => Align { h: HAlign::Center, v },
42                Align { h: HAlign::Center, v } => Align { h: HAlign::Right, v },
43                Align { h: HAlign::Right, v } => Align { h: HAlign::Left, v },
44            })
45        });
46    });
47
48    cursive.add_global_callback('v', |cursive| {
49        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
50            image_view.set_align(match image_view.align() {
51                Align { h, v: VAlign::Top } => Align { h, v: VAlign::Center },
52                Align { h, v: VAlign::Center } => Align { h, v: VAlign::Bottom },
53                Align { h, v: VAlign::Bottom } => Align { h, v: VAlign::Top },
54            })
55        });
56    });
57
58    cursive.add_global_callback('q', |cursive| cursive.quit());
59
60    cursive.run();
61}
pub fn with_sizing(self, sizing: Sizing) -> Self

Set sizing.

Chainable.

Examples found in repository?
examples/scrollable.rs (line 25)
12fn main() {
13    let mut cursive = default();
14
15    cursive.add_layer(
16        Panel::new(
17            ImageView::default()
18                .with_image(
19                    // This will decode the JPEG file on-demand
20                    // Note that RGBA is supported, too, if you need transparency
21                    Image::new_stream_from_jpeg_file(FILE, ImageFormat::RGB).expect("new_stream_from_jpeg_file"),
22                    // If you prefer to keep the image data in memory:
23                    // Image::new_owned_from_jpeg_file(FILE, ImageFormat::RGB, true).expect("new_owned_from_jpeg_file"),
24                )
25                .with_sizing(Sizing::original())
26                .scrollable()
27                .scroll_x(true),
28        )
29        .fixed_size((50, 20)),
30    );
31
32    cursive.add_global_callback('q', |cursive| cursive.quit());
33
34    cursive.run();
35}
pub fn align(&self) -> Align

Align.

Examples found in repository?
examples/positioning.rs (line 40)
18fn main() {
19    let mut cursive = default();
20
21    cursive.add_layer(Panel::new(
22        ImageView::default()
23            .with_image(Image::new_png_file(FILE).expect("new_png_file"))
24            .with_name(NAME)
25            .fixed_size((50, 20)),
26    ));
27
28    cursive.add_global_callback('s', |cursive| {
29        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
30            image_view.set_sizing(match image_view.sizing() {
31                Sizing::Shrink => Sizing::Fit,
32                Sizing::Fit => Sizing::Scale(3.),
33                Sizing::Scale(_) => Sizing::Shrink,
34            })
35        });
36    });
37
38    cursive.add_global_callback('h', |cursive| {
39        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
40            image_view.set_align(match image_view.align() {
41                Align { h: HAlign::Left, v } => Align { h: HAlign::Center, v },
42                Align { h: HAlign::Center, v } => Align { h: HAlign::Right, v },
43                Align { h: HAlign::Right, v } => Align { h: HAlign::Left, v },
44            })
45        });
46    });
47
48    cursive.add_global_callback('v', |cursive| {
49        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
50            image_view.set_align(match image_view.align() {
51                Align { h, v: VAlign::Top } => Align { h, v: VAlign::Center },
52                Align { h, v: VAlign::Center } => Align { h, v: VAlign::Bottom },
53                Align { h, v: VAlign::Bottom } => Align { h, v: VAlign::Top },
54            })
55        });
56    });
57
58    cursive.add_global_callback('q', |cursive| cursive.quit());
59
60    cursive.run();
61}
pub fn set_align(&mut self, align: Align)

Set align.

Examples found in repository?
examples/positioning.rs (lines 40-44)
18fn main() {
19    let mut cursive = default();
20
21    cursive.add_layer(Panel::new(
22        ImageView::default()
23            .with_image(Image::new_png_file(FILE).expect("new_png_file"))
24            .with_name(NAME)
25            .fixed_size((50, 20)),
26    ));
27
28    cursive.add_global_callback('s', |cursive| {
29        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
30            image_view.set_sizing(match image_view.sizing() {
31                Sizing::Shrink => Sizing::Fit,
32                Sizing::Fit => Sizing::Scale(3.),
33                Sizing::Scale(_) => Sizing::Shrink,
34            })
35        });
36    });
37
38    cursive.add_global_callback('h', |cursive| {
39        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
40            image_view.set_align(match image_view.align() {
41                Align { h: HAlign::Left, v } => Align { h: HAlign::Center, v },
42                Align { h: HAlign::Center, v } => Align { h: HAlign::Right, v },
43                Align { h: HAlign::Right, v } => Align { h: HAlign::Left, v },
44            })
45        });
46    });
47
48    cursive.add_global_callback('v', |cursive| {
49        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
50            image_view.set_align(match image_view.align() {
51                Align { h, v: VAlign::Top } => Align { h, v: VAlign::Center },
52                Align { h, v: VAlign::Center } => Align { h, v: VAlign::Bottom },
53                Align { h, v: VAlign::Bottom } => Align { h, v: VAlign::Top },
54            })
55        });
56    });
57
58    cursive.add_global_callback('q', |cursive| cursive.quit());
59
60    cursive.run();
61}
pub fn with_align(self, align: Align) -> Self

Set align.

Chainable.