ImageView

Struct ImageView 

pub struct ImageView { /* private fields */ }
Image view.

It will, of course, only work on terminals that support graphics. Relying on the viuer library, it supports the Kitty, iTerm, and Sixel (with the sixel feature) terminal graphics protocols.

The view supports fit or scale sizing modes (fit is the default), image alignment, and scrolling.

Implementations

Source

impl ImageView

pub fn image(&self) -> Option<&DynamicImage>

Image.

pub fn image_mut(&mut self) -> Option<&mut DynamicImage>

Image.

pub fn set_image(&mut self, image: DynamicImage)

Set image.

pub fn with_image(self, image: DynamicImage) -> Self

Set image.

Chainable.

pub fn set_image_file<PathT>(&mut self, path: PathT)
where PathT: AsRef<Path>,

Set image.

pub fn with_image_file<PathT>(self, path: PathT) -> Self
where PathT: AsRef<Path>,

Set image.

Chainable.

Examples found in repository?
examples/scrollable.rs (line 15)
10fn main() {
11    let mut cursive = default();
12
13    cursive.add_layer(
14        Panel::new(
15            ImageView::default().with_image_file(FILE).with_sizing(Sizing::original()).scrollable().scroll_x(true),
16        )
17        .fixed_size((50, 20)),
18    );
19
20    cursive.add_global_callback('q', |cursive| cursive.quit());
21
22    cursive.run();
23}
More examples
Hide additional examples
examples/simple.rs (line 14)
8fn main() {
9    let mut cursive = default();
10
11    // By default the image view uses "fit" sizing
12    // This means that it will require the minimal character box that fits the image
13
14    cursive.add_layer(Panel::new(ImageView::default().with_image_file(FILE)));
15
16    cursive.add_global_callback('q', |cursive| cursive.quit());
17
18    cursive.run();
19}
examples/positioning.rs (line 18)
15fn main() {
16    let mut cursive = default();
17
18    cursive.add_layer(Panel::new(ImageView::default().with_image_file(FILE).with_name(NAME).fixed_size((50, 20))));
19
20    cursive.add_global_callback('s', |cursive| {
21        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
22            image_view.set_sizing(match image_view.sizing() {
23                Sizing::Fit => Sizing::original(),
24                Sizing::Scale(_) => Sizing::Fit,
25            })
26        });
27    });
28
29    cursive.add_global_callback('h', |cursive| {
30        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
31            image_view.set_align(match image_view.align() {
32                Align { h: HAlign::Left, v } => Align { h: HAlign::Center, v },
33                Align { h: HAlign::Center, v } => Align { h: HAlign::Right, v },
34                Align { h: HAlign::Right, v } => Align { h: HAlign::Left, v },
35            })
36        });
37    });
38
39    cursive.add_global_callback('v', |cursive| {
40        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
41            image_view.set_align(match image_view.align() {
42                Align { h, v: VAlign::Top } => Align { h, v: VAlign::Center },
43                Align { h, v: VAlign::Center } => Align { h, v: VAlign::Bottom },
44                Align { h, v: VAlign::Bottom } => Align { h, v: VAlign::Top },
45            })
46        });
47    });
48
49    cursive.add_global_callback('q', |cursive| cursive.quit());
50
51    cursive.run();
52}
pub fn sizing(&self) -> Sizing

Sizing.

Examples found in repository?
examples/positioning.rs (line 22)
15fn main() {
16    let mut cursive = default();
17
18    cursive.add_layer(Panel::new(ImageView::default().with_image_file(FILE).with_name(NAME).fixed_size((50, 20))));
19
20    cursive.add_global_callback('s', |cursive| {
21        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
22            image_view.set_sizing(match image_view.sizing() {
23                Sizing::Fit => Sizing::original(),
24                Sizing::Scale(_) => Sizing::Fit,
25            })
26        });
27    });
28
29    cursive.add_global_callback('h', |cursive| {
30        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
31            image_view.set_align(match image_view.align() {
32                Align { h: HAlign::Left, v } => Align { h: HAlign::Center, v },
33                Align { h: HAlign::Center, v } => Align { h: HAlign::Right, v },
34                Align { h: HAlign::Right, v } => Align { h: HAlign::Left, v },
35            })
36        });
37    });
38
39    cursive.add_global_callback('v', |cursive| {
40        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
41            image_view.set_align(match image_view.align() {
42                Align { h, v: VAlign::Top } => Align { h, v: VAlign::Center },
43                Align { h, v: VAlign::Center } => Align { h, v: VAlign::Bottom },
44                Align { h, v: VAlign::Bottom } => Align { h, v: VAlign::Top },
45            })
46        });
47    });
48
49    cursive.add_global_callback('q', |cursive| cursive.quit());
50
51    cursive.run();
52}
pub fn set_sizing(&mut self, sizing: Sizing)

Set sizing.

Examples found in repository?
examples/positioning.rs (lines 22-25)
15fn main() {
16    let mut cursive = default();
17
18    cursive.add_layer(Panel::new(ImageView::default().with_image_file(FILE).with_name(NAME).fixed_size((50, 20))));
19
20    cursive.add_global_callback('s', |cursive| {
21        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
22            image_view.set_sizing(match image_view.sizing() {
23                Sizing::Fit => Sizing::original(),
24                Sizing::Scale(_) => Sizing::Fit,
25            })
26        });
27    });
28
29    cursive.add_global_callback('h', |cursive| {
30        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
31            image_view.set_align(match image_view.align() {
32                Align { h: HAlign::Left, v } => Align { h: HAlign::Center, v },
33                Align { h: HAlign::Center, v } => Align { h: HAlign::Right, v },
34                Align { h: HAlign::Right, v } => Align { h: HAlign::Left, v },
35            })
36        });
37    });
38
39    cursive.add_global_callback('v', |cursive| {
40        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
41            image_view.set_align(match image_view.align() {
42                Align { h, v: VAlign::Top } => Align { h, v: VAlign::Center },
43                Align { h, v: VAlign::Center } => Align { h, v: VAlign::Bottom },
44                Align { h, v: VAlign::Bottom } => Align { h, v: VAlign::Top },
45            })
46        });
47    });
48
49    cursive.add_global_callback('q', |cursive| cursive.quit());
50
51    cursive.run();
52}
pub fn with_sizing(self, sizing: Sizing) -> Self

Set sizing.

Chainable.

Examples found in repository?
examples/scrollable.rs (line 15)
10fn main() {
11    let mut cursive = default();
12
13    cursive.add_layer(
14        Panel::new(
15            ImageView::default().with_image_file(FILE).with_sizing(Sizing::original()).scrollable().scroll_x(true),
16        )
17        .fixed_size((50, 20)),
18    );
19
20    cursive.add_global_callback('q', |cursive| cursive.quit());
21
22    cursive.run();
23}
pub fn align(&self) -> Align

Align.

Examples found in repository?
examples/positioning.rs (line 31)
15fn main() {
16    let mut cursive = default();
17
18    cursive.add_layer(Panel::new(ImageView::default().with_image_file(FILE).with_name(NAME).fixed_size((50, 20))));
19
20    cursive.add_global_callback('s', |cursive| {
21        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
22            image_view.set_sizing(match image_view.sizing() {
23                Sizing::Fit => Sizing::original(),
24                Sizing::Scale(_) => Sizing::Fit,
25            })
26        });
27    });
28
29    cursive.add_global_callback('h', |cursive| {
30        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
31            image_view.set_align(match image_view.align() {
32                Align { h: HAlign::Left, v } => Align { h: HAlign::Center, v },
33                Align { h: HAlign::Center, v } => Align { h: HAlign::Right, v },
34                Align { h: HAlign::Right, v } => Align { h: HAlign::Left, v },
35            })
36        });
37    });
38
39    cursive.add_global_callback('v', |cursive| {
40        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
41            image_view.set_align(match image_view.align() {
42                Align { h, v: VAlign::Top } => Align { h, v: VAlign::Center },
43                Align { h, v: VAlign::Center } => Align { h, v: VAlign::Bottom },
44                Align { h, v: VAlign::Bottom } => Align { h, v: VAlign::Top },
45            })
46        });
47    });
48
49    cursive.add_global_callback('q', |cursive| cursive.quit());
50
51    cursive.run();
52}
pub fn set_align(&mut self, align: Align)

Set align.

Examples found in repository?
examples/positioning.rs (lines 31-35)
15fn main() {
16    let mut cursive = default();
17
18    cursive.add_layer(Panel::new(ImageView::default().with_image_file(FILE).with_name(NAME).fixed_size((50, 20))));
19
20    cursive.add_global_callback('s', |cursive| {
21        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
22            image_view.set_sizing(match image_view.sizing() {
23                Sizing::Fit => Sizing::original(),
24                Sizing::Scale(_) => Sizing::Fit,
25            })
26        });
27    });
28
29    cursive.add_global_callback('h', |cursive| {
30        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
31            image_view.set_align(match image_view.align() {
32                Align { h: HAlign::Left, v } => Align { h: HAlign::Center, v },
33                Align { h: HAlign::Center, v } => Align { h: HAlign::Right, v },
34                Align { h: HAlign::Right, v } => Align { h: HAlign::Left, v },
35            })
36        });
37    });
38
39    cursive.add_global_callback('v', |cursive| {
40        _ = cursive.call_on_name(NAME, |image_view: &mut ImageView| {
41            image_view.set_align(match image_view.align() {
42                Align { h, v: VAlign::Top } => Align { h, v: VAlign::Center },
43                Align { h, v: VAlign::Center } => Align { h, v: VAlign::Bottom },
44                Align { h, v: VAlign::Bottom } => Align { h, v: VAlign::Top },
45            })
46        });
47    });
48
49    cursive.add_global_callback('q', |cursive| cursive.quit());
50
51    cursive.run();
52}
pub fn with_align(self, align: Align) -> Self

Set align.

Chainable.